@@ -18,13 +18,17 @@
 
 
 import abc
-
-from oslo.config import cfg
+import croniter
+import datetime
+import pytz
 
 from ceilometerclient import client as ceiloclient
+from oslo.config import cfg
+import six
 
+from ceilometer.openstack.common.gettextutils import _  # noqa
 from ceilometer.openstack.common import log
-from ceilometer.openstack.common.gettextutils import _
+from ceilometer.openstack.common import timeutils
 
 LOG = log.getLogger(__name__)
 
@@ -33,11 +37,10 @@ OK = 'ok'
 ALARM = 'alarm'
 
 
+@six.add_metaclass(abc.ABCMeta)
 class Evaluator(object):
     """Base class for alarm rule evaluator plugins."""
 
-    __metaclass__ = abc.ABCMeta
-
     def __init__(self, notifier):
         self.notifier = notifier
         self.api_client = None
@@ -54,12 +57,13 @@ class Evaluator(object):
                 os_password=auth_config.os_password,
                 os_username=auth_config.os_username,
                 os_cacert=auth_config.os_cacert,
-                endpoint_type=auth_config.os_endpoint_type,
+                os_endpoint_type=auth_config.os_endpoint_type,
+                insecure=auth_config.insecure,
             )
             self.api_client = ceiloclient.get_client(2, **creds)
         return self.api_client
 
-    def _refresh(self, alarm, state, reason):
+    def _refresh(self, alarm, state, reason, reason_data):
         """Refresh alarm state."""
         try:
             previous = alarm.state
@@ -72,12 +76,49 @@ class Evaluator(object):
                 self._client.alarms.set_state(alarm.alarm_id, state=state)
             alarm.state = state
             if self.notifier:
-                self.notifier.notify(alarm, previous, reason)
+                self.notifier.notify(alarm, previous, reason, reason_data)
         except Exception:
             # retry will occur naturally on the next evaluation
             # cycle (unless alarm state reverts in the meantime)
             LOG.exception(_('alarm state update failed'))
 
+    @classmethod
+    def within_time_constraint(cls, alarm):
+        """Check whether the alarm is within at least one of its time
+        constraints. If there are none, then the answer is yes.
+        """
+        if not alarm.time_constraints:
+            return True
+
+        now_utc = timeutils.utcnow()
+        for tc in alarm.time_constraints:
+            tz = pytz.timezone(tc['timezone']) if tc['timezone'] else None
+            now_tz = now_utc.astimezone(tz) if tz else now_utc
+            start_cron = croniter.croniter(tc['start'], now_tz)
+            if cls._is_exact_match(start_cron, now_tz):
+                return True
+            latest_start = start_cron.get_prev(datetime.datetime)
+            duration = datetime.timedelta(seconds=tc['duration'])
+            if latest_start <= now_tz <= latest_start + duration:
+                return True
+        return False
+
+    @staticmethod
+    def _is_exact_match(cron, ts):
+        """Handle edge case where if the timestamp is the same as the
+        cron point in time to the minute, croniter returns the previous
+        start, not the current. We can check this by first going one
+        step back and then one step forward and check if we are
+        at the original point in time.
+        """
+        cron.get_prev()
+        diff = timeutils.total_seconds(ts - cron.get_next(datetime.datetime))
+        return abs(diff) < 60  # minute precision
+
     @abc.abstractmethod
     def evaluate(self, alarm):
-        pass
+        '''interface definition
+
+        evaluate an alarm
+        alarm Alarm: an instance of the Alarm
+        '''
