@@ -1,5 +1,9 @@
+# -*- encoding: utf-8 -*-
 #
-# Copyright 2013 Red Hat, Inc
+# Copyright © 2013 Red Hat, Inc
+#
+# Author: Eoghan Glynn <eglynn@redhat.com>
+# Author: Mehdi Abaakouk <mehdi.abaakouk@enovance.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -16,12 +20,11 @@
 import datetime
 import operator
 
-from oslo_log import log
-from oslo_utils import timeutils
-
 from ceilometer.alarm import evaluator
 from ceilometer.alarm.evaluator import utils
-from ceilometer.i18n import _, _LW
+from ceilometer.openstack.common.gettextutils import _  # noqa
+from ceilometer.openstack.common import log
+from ceilometer.openstack.common import timeutils
 
 LOG = log.getLogger(__name__)
 
@@ -41,6 +44,10 @@ class ThresholdEvaluator(evaluator.Evaluator):
     # for reporting/ingestion lag
     look_back = 1
 
+    # minimum number of datapoints within sliding window to
+    # avoid unknown state
+    quorum = 1
+
     @classmethod
     def _bound_duration(cls, alarm, constraints):
         """Bound the duration of the statistics query."""
@@ -53,8 +60,8 @@ class ThresholdEvaluator(evaluator.Evaluator):
         window = (alarm.rule['period'] *
                   (alarm.rule['evaluation_periods'] + look_back))
         start = now - datetime.timedelta(seconds=window)
-        LOG.debug('query stats from %(start)s to '
-                  '%(now)s', {'start': start, 'now': now})
+        LOG.debug(_('query stats from %(start)s to '
+                    '%(now)s') % {'start': start, 'now': now})
         after = dict(field='timestamp', op='ge', value=start.isoformat())
         before = dict(field='timestamp', op='le', value=now.isoformat())
         constraints.extend([before, after])
@@ -62,8 +69,9 @@ class ThresholdEvaluator(evaluator.Evaluator):
 
     @staticmethod
     def _sanitize(alarm, statistics):
-        """Sanitize statistics."""
-        LOG.debug('sanitize stats %s', statistics)
+        """Sanitize statistics.
+        """
+        LOG.debug(_('sanitize stats %s') % statistics)
         if alarm.rule.get('exclude_outliers'):
             key = operator.attrgetter('count')
             mean = utils.mean(statistics, key)
@@ -72,7 +80,7 @@ class ThresholdEvaluator(evaluator.Evaluator):
             upper = mean + 2 * stddev
             inliers, outliers = utils.anomalies(statistics, key, lower, upper)
             if outliers:
-                LOG.debug('excluded weak datapoints with sample counts %s',
+                LOG.debug(_('excluded weak datapoints with sample counts %s'),
                           [s.count for s in outliers])
                 statistics = inliers
             else:
@@ -81,12 +89,12 @@ class ThresholdEvaluator(evaluator.Evaluator):
         # in practice statistics are always sorted by period start, not
         # strictly required by the API though
         statistics = statistics[-alarm.rule['evaluation_periods']:]
-        LOG.debug('pruned statistics to %d', len(statistics))
+        LOG.debug(_('pruned statistics to %d') % len(statistics))
         return statistics
 
     def _statistics(self, alarm, query):
         """Retrieve statistics over the current window."""
-        LOG.debug('stats query %s', query)
+        LOG.debug(_('stats query %s') % query)
         try:
             return self._client.statistics.list(
                 meter_name=alarm.rule['meter_name'], q=query,
@@ -96,32 +104,23 @@ class ThresholdEvaluator(evaluator.Evaluator):
             return []
 
     def _sufficient(self, alarm, statistics):
-        """Check for the sufficiency of the data for evaluation.
-
-        Ensure there is sufficient data for evaluation, transitioning to
-        unknown otherwise.
+        """Ensure there is sufficient data for evaluation,
+           transitioning to unknown otherwise.
         """
-        sufficient = len(statistics) >= alarm.rule['evaluation_periods']
+        sufficient = len(statistics) >= self.quorum
         if not sufficient and alarm.state != evaluator.UNKNOWN:
-            LOG.warn(_LW('Expecting %(expected)d datapoints but only get '
-                         '%(actual)d') % {
-                'expected': alarm.rule['evaluation_periods'],
-                'actual': len(statistics)})
-            # Reason is not same as log message because we want to keep
-            # consistent since thirdparty software may depend on old format.
             reason = _('%d datapoints are unknown') % alarm.rule[
                 'evaluation_periods']
-            last = None if not statistics else (
-                getattr(statistics[-1], alarm.rule['statistic']))
             reason_data = self._reason_data('unknown',
                                             alarm.rule['evaluation_periods'],
-                                            last)
+                                            None)
             self._refresh(alarm, evaluator.UNKNOWN, reason, reason_data)
         return sufficient
 
     @staticmethod
     def _reason_data(disposition, count, most_recent):
-        """Create a reason data dictionary for this evaluator type."""
+        """Create a reason data dictionary for this evaluator type.
+        """
         return {'type': 'threshold', 'disposition': disposition,
                 'count': count, 'most_recent': most_recent}
 
@@ -175,8 +174,8 @@ class ThresholdEvaluator(evaluator.Evaluator):
 
     def evaluate(self, alarm):
         if not self.within_time_constraint(alarm):
-            LOG.debug('Attempted to evaluate alarm %s, but it is not '
-                      'within its time constraint.', alarm.alarm_id)
+            LOG.debug(_('Attempted to evaluate alarm %s, but it is not '
+                        'within its time constraint.') % alarm.alarm_id)
             return
 
         query = self._bound_duration(
@@ -194,10 +193,11 @@ class ThresholdEvaluator(evaluator.Evaluator):
                 op = COMPARATORS[alarm.rule['comparison_operator']]
                 value = getattr(stat, alarm.rule['statistic'])
                 limit = alarm.rule['threshold']
-                LOG.debug('comparing value %(value)s against threshold'
-                          ' %(limit)s', {'value': value, 'limit': limit})
+                LOG.debug(_('comparing value %(value)s against threshold'
+                            ' %(limit)s') %
+                          {'value': value, 'limit': limit})
                 return op(value, limit)
 
             self._transition(alarm,
                              statistics,
-                             [_compare(statistic) for statistic in statistics])
+                             map(_compare, statistics))
