@@ -20,20 +20,19 @@
 
 import abc
 
+from ceilometerclient import client as ceiloclient
 from oslo.config import cfg
+import six
 from stevedore import extension
 
-from ceilometer.alarm import rpc as rpc_alarm
 from ceilometer.alarm.partition import coordination
-from ceilometer.service import prepare_service
-from ceilometer.openstack.common import importutils
+from ceilometer.alarm import rpc as rpc_alarm
+from ceilometer.openstack.common.gettextutils import _  # noqa
 from ceilometer.openstack.common import log
 from ceilometer.openstack.common import network_utils
-from ceilometer.openstack.common import service as os_service
-from ceilometer.openstack.common.gettextutils import _
-from ceilometer.openstack.common.rpc import service as rpc_service
 from ceilometer.openstack.common.rpc import dispatcher as rpc_dispatcher
-from ceilometerclient import client as ceiloclient
+from ceilometer.openstack.common.rpc import service as rpc_service
+from ceilometer.openstack.common import service as os_service
 
 
 OPTS = [
@@ -44,9 +43,6 @@ OPTS = [
                     ' collection of underlying metrics.',
                deprecated_opts=[cfg.DeprecatedOpt(
                    'threshold_evaluation_interval', group='alarm')]),
-    cfg.StrOpt('evaluation_service',
-               default='ceilometer.alarm.service.SingletonAlarmService',
-               help='Class to launch as alarm evaluation service'),
 ]
 
 cfg.CONF.register_opts(OPTS, group='alarm')
@@ -58,10 +54,9 @@ cfg.CONF.import_opt('partition_rpc_topic', 'ceilometer.alarm.rpc',
 LOG = log.getLogger(__name__)
 
 
+@six.add_metaclass(abc.ABCMeta)
 class AlarmService(object):
 
-    __metaclass__ = abc.ABCMeta
-
     EXTENSIONS_NAMESPACE = "ceilometer.alarm.evaluator"
 
     def _load_evaluators(self):
@@ -85,7 +80,7 @@ class AlarmService(object):
                 os_password=auth_config.os_password,
                 os_username=auth_config.os_username,
                 os_cacert=auth_config.os_cacert,
-                endpoint_type=auth_config.os_endpoint_type,
+                os_endpoint_type=auth_config.os_endpoint_type,
                 insecure=auth_config.insecure,
             )
             self.api_client = ceiloclient.get_client(2, **creds)
@@ -139,12 +134,6 @@ class SingletonAlarmService(AlarmService, os_service.Service):
                                             'value': True}])
 
 
-def alarm_evaluator():
-    prepare_service()
-    service = importutils.import_object(cfg.CONF.alarm.evaluation_service)
-    os_service.launch(service).wait()
-
-
 cfg.CONF.import_opt('host', 'ceilometer.service')
 
 
@@ -161,7 +150,7 @@ class PartitionedAlarmService(AlarmService, rpc_service.Service):
         self.partition_coordinator = coordination.PartitionCoordinator()
 
     def initialize_service_hook(self, service):
-        LOG.debug('initialize_service_hooks')
+        LOG.debug(_('initialize_service_hooks'))
         self.conn.create_worker(
             cfg.CONF.alarm.partition_rpc_topic,
             rpc_dispatcher.RpcDispatcher([self]),
@@ -219,14 +208,15 @@ class AlarmNotifierService(rpc_service.Service):
         self.tg.add_timer(604800, lambda: None)
 
     def initialize_service_hook(self, service):
-        LOG.debug('initialize_service_hooks')
+        LOG.debug(_('initialize_service_hooks'))
         self.conn.create_worker(
             cfg.CONF.alarm.notifier_rpc_topic,
             rpc_dispatcher.RpcDispatcher([self]),
             'ceilometer.alarm.' + cfg.CONF.alarm.notifier_rpc_topic,
         )
 
-    def _handle_action(self, action, alarm_id, previous, current, reason):
+    def _handle_action(self, action, alarm_id, previous,
+                       current, reason, reason_data):
         try:
             action = network_utils.urlsplit(action)
         except Exception:
@@ -246,9 +236,10 @@ class AlarmNotifierService(rpc_service.Service):
             return
 
         try:
-            LOG.debug("Notifying alarm %s with action %s",
-                      alarm_id, action)
-            notifier.notify(action, alarm_id, previous, current, reason)
+            LOG.debug(_("Notifying alarm %(id)s with action %(act)s") % (
+                      {'id': alarm_id, 'act': action}))
+            notifier.notify(action, alarm_id, previous,
+                            current, reason, reason_data)
         except Exception:
             LOG.exception(_("Unable to notify alarm %s"), alarm_id)
             return
@@ -263,6 +254,7 @@ class AlarmNotifierService(rpc_service.Service):
         - previous, the previous state of the alarm
         - current, the new state the alarm has transitioned to
         - reason, the reason the alarm changed its state
+        - reason_data, a dict representation of the reason
 
         :param context: Request context.
         :param data: A dict as described above.
@@ -277,10 +269,5 @@ class AlarmNotifierService(rpc_service.Service):
                                 data.get('alarm_id'),
                                 data.get('previous'),
                                 data.get('current'),
-                                data.get('reason'))
-
-
-def alarm_notifier():
-    prepare_service()
-    os_service.launch(AlarmNotifierService(
-        cfg.CONF.host, 'ceilometer.alarm')).wait()
+                                data.get('reason'),
+                                data.get('reason_data'))
