@@ -26,15 +26,21 @@ from ceilometer.openstack.common import jsonutils
 from ceilometer import storage
 
 
-storage.register_opts(cfg.CONF)
+class JSONEncoder(flask.json.JSONEncoder):
+    @staticmethod
+    def default(o):
+        return jsonutils.to_primitive(o)
 
 
-def make_app(conf, enable_acl=True, attach_storage=True):
+def make_app(conf, enable_acl=True, attach_storage=True,
+             sources_file='sources.json'):
     app = flask.Flask('ceilometer.api')
     app.register_blueprint(v1_blueprint.blueprint, url_prefix='/v1')
 
+    app.json_encoder = JSONEncoder
+
     try:
-        with open("sources.json", "r") as f:
+        with open(sources_file, "r") as f:
             sources = jsonutils.load(f)
     except IOError:
         sources = {}
@@ -47,10 +53,8 @@ def make_app(conf, enable_acl=True, attach_storage=True):
     if attach_storage:
         @app.before_request
         def attach_storage():
-            storage_engine = storage.get_engine(conf)
-            flask.request.storage_engine = storage_engine
             flask.request.storage_conn = \
-                storage_engine.get_connection(conf)
+                storage.get_connection(conf)
 
     # Install the middleware wrapper
     if enable_acl:
