@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Cloudbase Solutions Srl
 #
 # Author: Claudiu Belu <cbelu@cloudbasesolutions.com>
@@ -20,9 +18,10 @@
 
 from oslo.config import cfg
 
-from ceilometer.compute.virt import inspector as virt_inspector
 from ceilometer.compute.virt.hyperv import utilsv2
+from ceilometer.compute.virt import inspector as virt_inspector
 from ceilometer.openstack.common import log
+from ceilometer.openstack.common import units
 
 CONF = cfg.CONF
 LOG = log.getLogger(__name__)
@@ -48,8 +47,7 @@ class HyperVInspector(virt_inspector.Inspector):
         cpu_percent_used = (cpu_clock_used /
                             float(host_cpu_clock * cpu_count))
         # Nanoseconds
-        cpu_time = (long(uptime * cpu_percent_used) *
-                    1000)
+        cpu_time = (long(uptime * cpu_percent_used) * units.k)
 
         return virt_inspector.CPUStats(number=cpu_count, time=cpu_time)
 
@@ -62,9 +60,9 @@ class HyperVInspector(virt_inspector.Inspector):
                 parameters=None)
 
             stats = virt_inspector.InterfaceStats(
-                rx_bytes=vnic_metrics['rx_bytes'],
+                rx_bytes=vnic_metrics['rx_mb'] * units.Mi,
                 rx_packets=0,
-                tx_bytes=vnic_metrics['tx_bytes'],
+                tx_bytes=vnic_metrics['tx_mb'] * units.Mi,
                 tx_packets=0)
 
             yield (interface, stats)
@@ -79,9 +77,9 @@ class HyperVInspector(virt_inspector.Inspector):
             stats = virt_inspector.DiskStats(
                 read_requests=0,
                 # Return bytes
-                read_bytes=disk_metrics['read_mb'] * 1024,
+                read_bytes=disk_metrics['read_mb'] * units.Mi,
                 write_requests=0,
-                write_bytes=disk_metrics['write_mb'] * 1024,
+                write_bytes=disk_metrics['write_mb'] * units.Mi,
                 errors=0)
 
             yield (disk, stats)
