@@ -1,6 +1,11 @@
+# -*- encoding: utf-8 -*-
 #
-# Copyright 2013 ZHAW SoE
-# Copyright 2014 Intel Corp.
+# Copyright © 2013 ZHAW SoE
+# Copyright © 2014 Intel Corp.
+#
+# Authors: Lucas Graf <graflu0@students.zhaw.ch>
+#          Toni Zehnder <zehndton@students.zhaw.ch>
+#          Lianhao Lu <lianhao.lu@intel.com>
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -15,9 +20,9 @@
 # under the License.
 
 import copy
+import urlparse
 
-from urllib import parse as urlparse
-
+from ceilometer.openstack.common import timeutils
 from ceilometer import sample
 
 
@@ -25,35 +30,23 @@ def get_metadata_from_host(host_url):
     return {'resource_url': urlparse.urlunsplit(host_url)}
 
 
-def make_resource_metadata(res_metadata=None, host_url=None):
+def make_sample_from_host(host_url, name, type, unit, volume,
+                          project_id=None, user_id=None, res_metadata=None):
     resource_metadata = dict()
     if res_metadata is not None:
         metadata = copy.copy(res_metadata)
-        resource_metadata.update(metadata)
+        resource_metadata = dict(zip(metadata._fields, metadata))
     resource_metadata.update(get_metadata_from_host(host_url))
-    return resource_metadata
 
-
-def make_sample_from_host(host_url, name, sample_type, unit, volume,
-                          project_id=None, user_id=None, resource_id=None,
-                          res_metadata=None, extra=None,
-                          name_prefix='hardware'):
-
-    extra = extra or {}
-    resource_metadata = make_resource_metadata(res_metadata, host_url)
-    resource_metadata.update(extra)
-
-    res_id = resource_id or extra.get('resource_id') or host_url.hostname
-    if name_prefix:
-        name = name_prefix + '.' + name
     return sample.Sample(
-        name=name,
-        type=sample_type,
+        name='hardware.' + name,
+        type=type,
         unit=unit,
         volume=volume,
-        user_id=user_id or extra.get('user_id'),
-        project_id=project_id or extra.get('project_id'),
-        resource_id=res_id,
+        user_id=project_id,
+        project_id=user_id,
+        resource_id=host_url.hostname,
+        timestamp=timeutils.isotime(),
         resource_metadata=resource_metadata,
         source='hardware',
     )
