@@ -15,14 +15,15 @@
 
 import abc
 
+import six
 
-class Driver(object, metaclass=abc.ABCMeta):
-    def __init__(self, conf):
-        self.conf = conf
+
+@six.add_metaclass(abc.ABCMeta)
+class Driver():
 
     @abc.abstractmethod
     def get_sample_data(self, meter_name, parse_url, params, cache):
-        """Return volume, resource_id, resource_metadata, timestamp in tuple.
+        '''Return volume, resource_id, resource_metadata, timestamp in tuple.
 
         If not implemented for meter_name, returns None
-        """
+        '''
