@@ -93,6 +93,8 @@ CLI_OPTIONS = [
 ]
 cfg.CONF.register_cli_opts(CLI_OPTIONS, group="service_credentials")
 
+cfg.CONF.import_opt('default_log_levels',
+                    'ceilometer.openstack.common.log')
 
 LOG = log.getLogger(__name__)
 
@@ -107,7 +109,6 @@ class DispatchedService(object):
     DISPATCHER_NAMESPACE = 'ceilometer.dispatcher'
 
     def start(self):
-        super(DispatchedService, self).start()
         LOG.debug(_('loading dispatchers from %s'),
                   self.DISPATCHER_NAMESPACE)
         self.dispatcher_manager = named.NamedExtensionManager(
@@ -118,6 +119,8 @@ class DispatchedService(object):
         if not list(self.dispatcher_manager):
             LOG.warning(_('Failed to load any dispatchers for %s'),
                         self.DISPATCHER_NAMESPACE)
+        # ensure dispatcher is configured before starting other services
+        super(DispatchedService, self).start()
 
 
 def get_workers(name):
@@ -135,15 +138,10 @@ def prepare_service(argv=None):
     gettextutils.install('ceilometer', lazy=True)
     gettextutils.enable_lazy()
     rpc.set_defaults(control_exchange='ceilometer')
+    log_levels = (cfg.CONF.default_log_levels +
+                  ['stevedore=INFO', 'keystoneclient=INFO'])
     cfg.set_defaults(log.log_opts,
-                     default_log_levels=['amqplib=WARN',
-                                         'qpid.messaging=INFO',
-                                         'sqlalchemy=WARN',
-                                         'keystoneclient=INFO',
-                                         'stevedore=INFO',
-                                         'eventlet.wsgi.server=WARN',
-                                         'iso8601=WARN'
-                                         ])
+                     default_log_levels=log_levels)
     if argv is None:
         argv = sys.argv
     cfg.CONF(argv[1:], project='ceilometer')
