@@ -1,3 +1,4 @@
+# -*- encoding: utf-8 -*-
 
 # Copyright 2013 OpenStack Foundation
 # All Rights Reserved.
@@ -16,6 +17,7 @@
 # under the License.
 
 from sqlalchemy import BigInteger
+from sqlalchemy import Integer
 from sqlalchemy import MetaData
 from sqlalchemy import Table
 
@@ -24,3 +26,9 @@ def upgrade(migrate_engine):
     meta = MetaData(bind=migrate_engine)
     resource = Table('metadata_int', meta, autoload=True)
     resource.c.value.alter(type=BigInteger)
+
+
+def downgrade(migrate_engine):
+    meta = MetaData(bind=migrate_engine)
+    resource = Table('metadata_int', meta, autoload=True)
+    resource.c.value.alter(type=Integer)
