@@ -1,3 +1,4 @@
+# -*- encoding: utf-8 -*-
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -19,3 +20,9 @@ def upgrade(migrate_engine):
     meta = MetaData(bind=migrate_engine)
     users = Table('alarm', meta, autoload=True)
     users.c.id.alter(name='alarm_id')
+
+
+def downgrade(migrate_engine):
+    meta = MetaData(bind=migrate_engine)
+    users = Table('alarm', meta, autoload=True)
+    users.c.alarm_id.alter(name='id')
